{ config,
  pkgs,
  ... }:

let
  gitpkgs = import <gitpkgs> {};
in
{
  nixpkgs.config = {
    allowBroken = false;

    packageOverrides = pkgs: rec {
      goPackages = gitpkgs.go16Packages;
      bluez = pkgs.bluez5;
      linuxPackages = pkgs.linuxPackages_latest;
      #pythonPackages.sqlalchemy7 = pkgs.pythonPackages.sqlalchemy7.override { doCheck = false; };
    };

    allowUnfree = true;

    chromium = {
      enablePepperFlash = true;
      enablePepperPDF = true;
    };

    firefox = {
      enableGoogleTalkPlugin = true;
      enableAdobeFlash = false;
    };

    pidgin = {
      openssl = true;
      gnutls = true;
    };

    keepass = pkgs.keepass.override {
      plugins = [ pkgs.keepass-keefox ];
    };

# TODO: implement support for this
#    libvirt = {
#      xenSupport = false;
#    };

  };

  imports =
    [
      ../common/pkg/default.nix
      ../common/pkg/neovim.nix
    ];

  environment.systemPackages = with pkgs; [
    androidsdk_4_4

    nixops
    ansible 

    gnupg
    picocom
    xfce.terminal
    xorg.xbacklight
    coreutils
    lsof

    xscreensaver
    firefox-wrapper
    chromium
    seafile-client

    qpdfview
    thunderbird
    pidgin
    hexchat
    keepass
    skype

    remmina
    teamviewer
    x11_ssh_askpass
    gnome3.dconf # needed by virtmanager
    virtmanager

    vlc
    audacity
    pavucontrol
    spotify
    
    gimp
    inkscape
    pdftk
    imagemagick

    iptables
    nftables
    iperf

    pandoc
    pythonFull
  ] ++ [
    gitpkgs.rkt
    gitpkgs.flannel
  ];
}
